@@ -1,10 +1,9 @@
-# -*- coding: utf-8 -*-
 # Natural Language Toolkit: Twitter client
 #
-# Copyright (C) 2001-2020 NLTK Project
+# Copyright (C) 2001-2024 NLTK Project
 # Author: Ewan Klein <ewan@inf.ed.ac.uk>
 #         Lorenzo Rubio <lrnzcig@gmail.com>
-# URL: <http://nltk.org/>
+# URL: <https://www.nltk.org/>
 # For license information, see LICENSE.TXT
 
 
@@ -24,19 +23,18 @@ divided into 15 minute windows.
 """
 
 import datetime
+import gzip
 import itertools
 import json
 import os
 import time
-import gzip
 
 import requests
-
 from twython import Twython, TwythonStreamer
-from twython.exceptions import TwythonRateLimitError, TwythonError
+from twython.exceptions import TwythonError, TwythonRateLimitError
 
+from nltk.twitter.api import BasicTweetHandler, TweetHandlerI
 from nltk.twitter.util import credsfromfile, guess_path
-from nltk.twitter.api import TweetHandlerI, BasicTweetHandler
 
 
 class Streamer(TwythonStreamer):
@@ -44,11 +42,10 @@ class Streamer(TwythonStreamer):
     Retrieve data from the Twitter Streaming API.
 
     The streaming API requires
-    `OAuth 1.0 <http://en.wikipedia.org/wiki/OAuth>`_ authentication.
+    `OAuth 1.0 <https://en.wikipedia.org/wiki/OAuth>`_ authentication.
     """
 
     def __init__(self, app_key, app_secret, oauth_token, oauth_token_secret):
-
         self.handler = None
         self.do_continue = True
         TwythonStreamer.__init__(
@@ -92,7 +89,6 @@ class Streamer(TwythonStreamer):
         Wrapper for 'statuses / sample' API call
         """
         while self.do_continue:
-
             # Stream in an endless loop until limit is reached. See twython
             # issue 288: https://github.com/ryanmcgrath/twython/issues/288
             # colditzjb commented on 9 Dec 2014
@@ -101,7 +97,7 @@ class Streamer(TwythonStreamer):
                 self.statuses.sample()
             except requests.exceptions.ChunkedEncodingError as e:
                 if e is not None:
-                    print("Error (stream will continue): {0}".format(e))
+                    print(f"Error (stream will continue): {e}")
                 continue
 
     def filter(self, track="", follow="", lang="en"):
@@ -118,7 +114,7 @@ class Streamer(TwythonStreamer):
                 self.statuses.filter(track=track, follow=follow, lang=lang)
             except requests.exceptions.ChunkedEncodingError as e:
                 if e is not None:
-                    print("Error (stream will continue): {0}".format(e))
+                    print(f"Error (stream will continue): {e}")
                 continue
 
 
@@ -128,6 +124,14 @@ class Query(Twython):
     """
 
     def __init__(self, app_key, app_secret, oauth_token, oauth_token_secret):
+        """
+        :param app_key: (optional) Your applications key
+        :param app_secret: (optional) Your applications secret key
+        :param oauth_token: (optional) When using **OAuth 1**, combined with
+            oauth_token_secret to make authenticated calls
+        :param oauth_token_secret: (optional) When using **OAuth 1** combined
+            with oauth_token to make authenticated calls
+        """
         self.handler = None
         self.do_continue = True
         Twython.__init__(self, app_key, app_secret, oauth_token, oauth_token_secret)
@@ -157,7 +161,7 @@ class Query(Twython):
         ids = [line.strip() for line in ids_f if line]
 
         if verbose:
-            print("Counted {0} Tweet IDs in {1}.".format(len(ids), ids_f))
+            print(f"Counted {len(ids)} Tweet IDs in {ids_f}.")
 
         # The Twitter endpoint takes lists of up to 100 ids, so we chunk the
         # ids.
@@ -249,11 +253,11 @@ class Query(Twython):
                     result_type="recent",
                 )
             except TwythonRateLimitError as e:
-                print("Waiting for 15 minutes -{0}".format(e))
+                print(f"Waiting for 15 minutes -{e}")
                 time.sleep(15 * 60)  # wait 15 minutes
                 continue
             except TwythonError as e:
-                print("Fatal error in Twython request -{0}".format(e))
+                print(f"Fatal error in Twython request -{e}")
                 if retries_after_twython_exception == retries:
                     raise e
                 retries += 1
@@ -303,7 +307,7 @@ class Query(Twython):
             self.handler.handle(item)
 
 
-class Twitter(object):
+class Twitter:
     """
     Wrapper class with restricted functionality and fewer options.
     """
@@ -331,28 +335,28 @@ class Twitter(object):
         :param str keywords: Keywords to use for searching or filtering
         :param list follow: UserIDs to use for filtering Tweets from the public stream
         :param bool to_screen: If `True`, display the tweet texts on the screen,\
-        otherwise print to a file
+            otherwise print to a file
 
         :param bool stream: If `True`, use the live public stream,\
-        otherwise search past public Tweets
+            otherwise search past public Tweets
 
         :param int limit: The number of data items to process in the current\
-        round of processing.
+            round of processing.
 
         :param tuple date_limit: The date at which to stop collecting\
-        new data. This should be entered as a tuple which can serve as the\
-        argument to `datetime.datetime`.\
-        E.g. `date_limit=(2015, 4, 1, 12, 40)` for 12:30 pm on April 1 2015.
-        Note that, in the case of streaming, this is the maximum date, i.e.\
-        a date in the future; if not, it is the minimum date, i.e. a date\
-        in the past
+            new data. This should be entered as a tuple which can serve as the\
+            argument to `datetime.datetime`.\
+            E.g. `date_limit=(2015, 4, 1, 12, 40)` for 12:30 pm on April 1 2015.
+            Note that, in the case of streaming, this is the maximum date, i.e.\
+            a date in the future; if not, it is the minimum date, i.e. a date\
+            in the past
 
         :param str lang: language
 
         :param bool repeat: A flag to determine whether multiple files should\
-        be written. If `True`, the length of each file will be set by the\
-        value of `limit`. Use only if `to_screen` is `False`. See also
-        :py:func:`handle`.
+            be written. If `True`, the length of each file will be set by the\
+            value of `limit`. Use only if `to_screen` is `False`. See also
+            :py:func:`handle`.
 
         :param gzip_compress: if `True`, output files are compressed with gzip.
         """
@@ -431,7 +435,7 @@ class TweetViewer(TweetHandlerI):
             return
 
     def on_finish(self):
-        print("Written {0} Tweets".format(self.counter))
+        print(f"Written {self.counter} Tweets")
 
 
 class TweetWriter(TweetHandlerI):
@@ -475,7 +479,7 @@ class TweetWriter(TweetHandlerI):
         written. If `True`, the length of each file will be set by the value\
         of `limit`. See also :py:func:`handle`.
 
-        :param gzip_compress: if `True`, ouput files are compressed with gzip.
+        :param gzip_compress: if `True`, output files are compressed with gzip.
         """
         self.fprefix = fprefix
         self.subdir = guess_path(subdir)
@@ -503,7 +507,7 @@ class TweetWriter(TweetHandlerI):
             suffix = ".gz"
         else:
             suffix = ""
-        outfile = "{0}.{1}.json{2}".format(fname, timestamp, suffix)
+        outfile = f"{fname}.{timestamp}.json{suffix}"
         return outfile
 
     def handle(self, data):
@@ -518,7 +522,7 @@ class TweetWriter(TweetHandlerI):
                 self.output = gzip.open(self.fname, "w")
             else:
                 self.output = open(self.fname, "w")
-            print("Writing to {0}".format(self.fname))
+            print(f"Writing to {self.fname}")
 
         json_data = json.dumps(data)
         if self.gzip_compress:
@@ -533,7 +537,7 @@ class TweetWriter(TweetHandlerI):
         self.startingup = False
 
     def on_finish(self):
-        print("Written {0} Tweets".format(self.counter))
+        print(f"Written {self.counter} Tweets")
         if self.output:
             self.output.close()
 
